@@ -106,7 +106,8 @@ exportRecords_offline <- function(dataFile, metaDataFile,
                   meta_data = meta_data, 
                   factors = factors, 
                   dates = dates, 
-                  checkboxLabels = checkboxLabels)
+                  checkboxLabels = checkboxLabels,
+                  ...)
   
   if (labels){
     x[,suffixed$name_suffix] <-
